==> haskell-language-javascript-0.5.14.2-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-language-javascript/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-javascript
version: 0.5.14.2
id: language-javascript-0.5.14.2-6bbe7a7f2ab2c66102707254c179bf08
key: langu_960JHyir9P0HFNpcsVITan
license: BSD3
copyright: (c) 2010-2015 Alan Zimmerman, 2015 Erik de Castro Lopo
maintainer: Erik de Castro Lopo <erikd@mega-nerd.com>
homepage: http://github.com/erikd/language-javascript
synopsis: Parser for JavaScript
description:
    Parses Javascript into an Abstract Syntax Tree (AST).  Initially intended as frontend to hjsmin.
    .
    Note: Version 0.5.0 breaks compatibility with prior versions, the AST has been reworked to allow
    round trip processing of JavaScript.
category: Language
author: Alan Zimmerman
exposed: True
exposed-modules:
    Language.JavaScript.Parser Language.JavaScript.Parser.Parser
    Language.JavaScript.Parser.Lexer
    Language.JavaScript.Parser.Grammar5 Language.JavaScript.Parser.AST
    Language.JavaScript.Pretty.Printer
    Language.JavaScript.Parser.SrcLocation
hidden-modules: Language.JavaScript.Parser.LexerUtils
                Language.JavaScript.Parser.ParseError
                Language.JavaScript.Parser.ParserMonad
                Language.JavaScript.Parser.StringEscape
                Language.JavaScript.Parser.Token
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/language-javascript-0.5.14.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/language-javascript-0.5.14.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/language-javascript-0.5.14.2
hs-libraries: HSlanguage-javascript-0.5.14.2-960JHyir9P0HFNpcsVITan
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-adef087994cafeb1970772b79d5f710a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
haddock-interfaces: /usr/share/doc/haskell-language-javascript/html/language-javascript.haddock
haddock-html: /usr/share/doc/haskell-language-javascript/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-language-javascript-0.5.14.2-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-language-javascript/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-javascript
version: 0.5.14.2
id: language-javascript-0.5.14.2-f55c8cd80a337ed6a6cb1df128d3b4c5
key: langu_BhFaTT7igFaCeyrexEX89r
license: BSD3
copyright: (c) 2010-2015 Alan Zimmerman, 2015 Erik de Castro Lopo
maintainer: Erik de Castro Lopo <erikd@mega-nerd.com>
homepage: http://github.com/erikd/language-javascript
synopsis: Parser for JavaScript
description:
    Parses Javascript into an Abstract Syntax Tree (AST).  Initially intended as frontend to hjsmin.
    .
    Note: Version 0.5.0 breaks compatibility with prior versions, the AST has been reworked to allow
    round trip processing of JavaScript.
category: Language
author: Alan Zimmerman
exposed: True
exposed-modules:
    Language.JavaScript.Parser Language.JavaScript.Parser.Parser
    Language.JavaScript.Parser.Lexer
    Language.JavaScript.Parser.Grammar5 Language.JavaScript.Parser.AST
    Language.JavaScript.Pretty.Printer
    Language.JavaScript.Parser.SrcLocation
hidden-modules: Language.JavaScript.Parser.LexerUtils
                Language.JavaScript.Parser.ParseError
                Language.JavaScript.Parser.ParserMonad
                Language.JavaScript.Parser.StringEscape
                Language.JavaScript.Parser.Token
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/language-javascript-0.5.14.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/language-javascript-0.5.14.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/language-javascript-0.5.14.2
hs-libraries: HSlanguage-javascript-0.5.14.2-BhFaTT7igFaCeyrexEX89r
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
haddock-interfaces: /usr/share/doc/haskell-language-javascript/html/language-javascript.haddock
haddock-html: /usr/share/doc/haskell-language-javascript/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
